import { Directive } from '@angular/core';
import { AsyncValidator, NG_ASYNC_VALIDATORS, AbstractControl, ValidationErrors } from '@angular/forms';
import { Observable } from "rxjs";
import { debounceTime, map } from "rxjs/operators";
import { UserService } from './user.service';

@Directive({
  selector: '[usernameExists]',
  standalone: true,
  providers: [{ provide: NG_ASYNC_VALIDATORS, useExisting: ExistingUsernameValidatorDirective, multi: true }]
})
export class ExistingUsernameValidatorDirective implements AsyncValidator {
  constructor(private userService: UserService) { }
  validate(control: AbstractControl): Observable<ValidationErrors | null> {
    return this.userService.getUsernames(control.value).pipe(
      debounceTime(1000),
      map((usernames: string[]) => {
        return (usernames && usernames.length > 0) ? { "nameExists": true } : null;
      })
    );
  }
}